@@ -1,24 +1,16 @@
-(* Lightweight thread library for OCaml
- * http://www.ocsigen.org/lwt
- * Module Lwt_engine
- * Copyright (C) 2011 Jérémie Dimino
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, with linking exceptions;
- * either version 2.1 of the License, or (at your option) any later
- * version. See COPYING file for details.
- *
- * This program is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
- *)
+(* This file is part of Lwt, released under the MIT license. See LICENSE.md for
+   details, or visit https://github.com/ocsigen/lwt/blob/master/LICENSE.md. *)
+
+
+
+(* [Lwt_sequence] is deprecated – we don't want users outside Lwt using it.
+   However, it is still used internally by Lwt. So, briefly disable warning 3
+   ("deprecated"), and create a local, non-deprecated alias for
+   [Lwt_sequence] that can be referred to by the rest of the code in this
+   module without triggering any more warnings. *)
+[@@@ocaml.warning "-3"]
+module Lwt_sequence = Lwt_sequence
+[@@@ocaml.warning "+3"]
 
 (* +-----------------------------------------------------------------+
    | Events                                                          |
@@ -59,15 +51,15 @@ class virtual abstract = object(self)
   method virtual private register_timer : float -> bool -> (unit -> unit) -> unit Lazy.t
 
   val readables = Lwt_sequence.create ()
-    (* Sequence of callbacks waiting for a file descriptor to become
-       readable. *)
+  (* Sequence of callbacks waiting for a file descriptor to become
+     readable. *)
 
   val writables = Lwt_sequence.create ()
-    (* Sequence of callbacks waiting for a file descriptor to become
-       writable. *)
+  (* Sequence of callbacks waiting for a file descriptor to become
+     writable. *)
 
   val timers = Lwt_sequence.create ()
-    (* Sequence of timers. *)
+  (* Sequence of timers. *)
 
   method destroy =
     Lwt_sequence.iter_l (fun (_fd, _f, _g, ev) -> stop_event ev) readables;
@@ -175,7 +167,7 @@ external ev_io_stop : ev_loop -> ev_io -> unit = "lwt_libev_io_stop"
 external ev_timer_init : ev_loop -> float -> bool -> (unit -> unit) -> ev_timer = "lwt_libev_timer_init"
 external ev_timer_stop : ev_loop -> ev_timer -> unit  = "lwt_libev_timer_stop"
 
-class libev' ?(backend=Ev_backend.default) () = object
+class libev ?(backend=Ev_backend.default) () = object
   inherit abstract
 
   val loop = ev_init backend
@@ -203,7 +195,7 @@ class libev' ?(backend=Ev_backend.default) () = object
     lazy(ev_timer_stop loop ev)
 end
 
-class libev = libev' ()
+class libev_deprecated = libev ()
 
 (* +-----------------------------------------------------------------+
    | Select/poll based engines                                       |
@@ -223,36 +215,36 @@ type sleeper = {
 
 module Sleep_queue =
   Lwt_pqueue.Make(struct
-                    type t = sleeper
-                    let compare {time = t1; _} {time = t2; _} = compare t1 t2
-                  end)
+    type t = sleeper
+    let compare {time = t1; _} {time = t2; _} = compare t1 t2
+  end)
   [@@ocaml.warning "-3"]
 
 module Fd_map = Map.Make(struct type t = Unix.file_descr let compare = compare end)
 
 let rec restart_actions sleep_queue now =
   match Sleep_queue.lookup_min sleep_queue with
-    | Some{ stopped = true; _ } ->
-        restart_actions (Sleep_queue.remove_min sleep_queue) now
-    | Some{ time = time; action = action; _ } when time <= now ->
-        (* We have to remove the sleeper to the queue before performing
-           the action. The action can change the sleeper's time, and this
-           might break the priority queue invariant if the sleeper is
-           still in the queue. *)
-        let q = Sleep_queue.remove_min sleep_queue in
-        action ();
-        restart_actions q now
-    | _ ->
-        sleep_queue
+  | Some{ stopped = true; _ } ->
+    restart_actions (Sleep_queue.remove_min sleep_queue) now
+  | Some{ time = time; action = action; _ } when time <= now ->
+    (* We have to remove the sleeper to the queue before performing
+       the action. The action can change the sleeper's time, and this
+       might break the priority queue invariant if the sleeper is
+       still in the queue. *)
+    let q = Sleep_queue.remove_min sleep_queue in
+    action ();
+    restart_actions q now
+  | _ ->
+    sleep_queue
 
 let rec get_next_timeout sleep_queue =
   match Sleep_queue.lookup_min sleep_queue with
-    | Some{ stopped = true; _ } ->
-        get_next_timeout (Sleep_queue.remove_min sleep_queue)
-    | Some{ time = time; _ } ->
-        max 0. (time -. Unix.gettimeofday ())
-    | None ->
-        -1.
+  | Some{ stopped = true; _ } ->
+    get_next_timeout (Sleep_queue.remove_min sleep_queue)
+  | Some{ time = time; _ } ->
+    max 0. (time -. Unix.gettimeofday ())
+  | None ->
+    -1.
 
 let bad_fd fd =
   try
@@ -263,28 +255,28 @@ let bad_fd fd =
 
 let invoke_actions fd map =
   match try Some(Fd_map.find fd map) with Not_found -> None with
-    | Some actions -> Lwt_sequence.iter_l (fun f -> f ()) actions
-    | None -> ()
+  | Some actions -> Lwt_sequence.iter_l (fun f -> f ()) actions
+  | None -> ()
 
 class virtual select_or_poll_based = object
   inherit abstract
 
   val mutable sleep_queue = Sleep_queue.empty
-    (* Threads waiting for a timeout to expire. *)
+  (* Threads waiting for a timeout to expire. *)
 
   val mutable new_sleeps = []
-    (* Sleepers added since the last iteration of the main loop:
+  (* Sleepers added since the last iteration of the main loop:
 
-       They are not added immediately to the main sleep queue in order
-       to prevent them from being wakeup immediately.  *)
+     They are not added immediately to the main sleep queue in order
+     to prevent them from being wakeup immediately.  *)
 
   val mutable wait_readable = Fd_map.empty
-    (* Sequences of actions waiting for file descriptors to become
-       readable. *)
+  (* Sequences of actions waiting for file descriptors to become
+     readable. *)
 
   val mutable wait_writable = Fd_map.empty
-    (* Sequences of actions waiting for file descriptors to become
-       writable. *)
+  (* Sequences of actions waiting for file descriptors to become
+     writable. *)
 
   method private cleanup = ()
 
@@ -351,13 +343,13 @@ class virtual select_based = object(self)
       try
         self#select fds_r fds_w timeout
       with
-        | Unix.Unix_error (Unix.EINTR, _, _) ->
-            ([], [])
-        | Unix.Unix_error (Unix.EBADF, _, _) ->
-            (* Keeps only bad file descriptors. Actions registered on
-               them have to handle the error: *)
-            (List.filter bad_fd fds_r,
-             List.filter bad_fd fds_w)
+      | Unix.Unix_error (Unix.EINTR, _, _) ->
+        ([], [])
+      | Unix.Unix_error (Unix.EBADF, _, _) ->
+        (* Keeps only bad file descriptors. Actions registered on
+           them have to handle the error: *)
+        (List.filter bad_fd fds_r,
+         List.filter bad_fd fds_w)
     in
     (* Restart threads waiting for a timeout: *)
     sleep_queue <- restart_actions sleep_queue (Unix.gettimeofday ());
@@ -387,12 +379,12 @@ class virtual poll_based = object(self)
       try
         self#poll fds timeout
       with
-        | Unix.Unix_error (Unix.EINTR, _, _) ->
-            []
-        | Unix.Unix_error (Unix.EBADF, _, _) ->
-            (* Keeps only bad file descriptors. Actions registered on
-               them have to handle the error: *)
-            List.filter (fun (fd, _, _) -> bad_fd fd) fds
+      | Unix.Unix_error (Unix.EINTR, _, _) ->
+        []
+      | Unix.Unix_error (Unix.EBADF, _, _) ->
+        (* Keeps only bad file descriptors. Actions registered on
+           them have to handle the error: *)
+        List.filter (fun (fd, _, _) -> bad_fd fd) fds
     in
     (* Restart threads waiting for a timeout: *)
     sleep_queue <- restart_actions sleep_queue (Unix.gettimeofday ());
@@ -418,7 +410,7 @@ end
 
 let current =
   if Lwt_config._HAVE_LIBEV && Lwt_config.libev_default then
-    ref (new libev :> t)
+    ref (new libev () :> t)
   else
     ref (new select :> t)
 
@@ -441,6 +433,6 @@ let timer_count () = !current#timer_count
 
 module Versioned =
 struct
-  class libev_1 = libev
-  class libev_2 = libev'
+  class libev_1 = libev_deprecated
+  class libev_2 = libev
 end
