@@ -631,6 +631,12 @@ let wait_read ch =
 
 external stub_read : Unix.file_descr -> Bytes.t -> int -> int -> int = "lwt_unix_read"
 external read_job : Unix.file_descr -> Bytes.t -> int -> int -> int job = "lwt_unix_read_job"
+external stub_pread :
+  Unix.file_descr -> Bytes.t -> file_offset:int -> int -> int -> int =
+    "lwt_unix_pread"
+external pread_job :
+  Unix.file_descr -> Bytes.t -> file_offset:int -> int -> int -> int job =
+    "lwt_unix_pread_job"
 
 let read ch buf pos len =
   if pos < 0 || len < 0 || pos > Bytes.length buf - len then
@@ -643,6 +649,17 @@ let read ch buf pos len =
     | false ->
       wrap_syscall Read ch (fun () -> stub_read ch.fd buf pos len)
 
+let pread ch buf ~file_offset pos len =
+  if pos < 0 || len < 0 || pos > Bytes.length buf - len then
+    invalid_arg "Lwt_unix.pread"
+  else
+    Lazy.force ch.blocking >>= function
+    | true ->
+      wait_read ch >>= fun () ->
+      run_job (pread_job ch.fd buf ~file_offset pos len)
+    | false ->
+      wrap_syscall Read ch (fun () -> stub_pread ch.fd buf ~file_offset pos len)
+
 external stub_read_bigarray :
   Unix.file_descr -> bigarray -> int -> int -> int = "lwt_unix_bytes_read"
 external read_bigarray_job :
@@ -672,6 +689,12 @@ let wait_write ch =
 
 external stub_write : Unix.file_descr -> Bytes.t -> int -> int -> int = "lwt_unix_write"
 external write_job : Unix.file_descr -> Bytes.t -> int -> int -> int job = "lwt_unix_write_job"
+external stub_pwrite :
+  Unix.file_descr -> Bytes.t -> file_offset:int -> int -> int -> int =
+    "lwt_unix_pwrite"
+external pwrite_job :
+  Unix.file_descr -> Bytes.t -> file_offset:int -> int -> int -> int job =
+    "lwt_unix_pwrite_job"
 
 let write ch buf pos len =
   if pos < 0 || len < 0 || pos > Bytes.length buf - len then
@@ -684,10 +707,25 @@ let write ch buf pos len =
     | false ->
       wrap_syscall Write ch (fun () -> stub_write ch.fd buf pos len)
 
+let pwrite ch buf ~file_offset pos len =
+  if pos < 0 || len < 0 || pos > Bytes.length buf - len then
+    invalid_arg "Lwt_unix.pwrite"
+  else
+    Lazy.force ch.blocking >>= function
+    | true ->
+      wait_write ch >>= fun () ->
+      run_job (pwrite_job ch.fd buf ~file_offset pos len)
+    | false ->
+      wrap_syscall Write ch (fun () -> stub_pwrite ch.fd buf ~file_offset pos len)
+
 let write_string ch buf pos len =
   let buf = Bytes.unsafe_of_string buf in
   write ch buf pos len
 
+let pwrite_string ch buf ~file_offset pos len =
+  let buf = Bytes.unsafe_of_string buf in
+  pwrite ch buf ~file_offset pos len
+
 external stub_write_bigarray :
   Unix.file_descr -> bigarray -> int -> int -> int = "lwt_unix_bytes_write"
 external write_bigarray_job :
@@ -1643,8 +1681,20 @@ let socketpair dom typ proto =
   let (s1, s2) = do_socketpair dom typ proto in
   (mk_ch ~blocking:false s1, mk_ch ~blocking:false s2)
 
+external accept4 :
+  close_on_exec:bool -> nonblock:bool -> Unix.file_descr ->
+    Unix.file_descr * Unix.sockaddr = "lwt_unix_accept4"
+
+let accept_and_set_nonblock ch_fd =
+  if Lwt_config._HAVE_ACCEPT4 then
+    let (fd, addr) = accept4 ~close_on_exec:false ~nonblock:true ch_fd in
+    (mk_ch ~blocking:false ~set_flags:false fd, addr)
+  else
+    let (fd, addr) = Unix.accept ch_fd in
+    (mk_ch ~blocking:false fd, addr)
+
 let accept ch =
-  wrap_syscall Read ch (fun _ -> let (fd, addr) = Unix.accept ch.fd in (mk_ch ~blocking:false fd, addr))
+  wrap_syscall Read ch (fun _ -> accept_and_set_nonblock ch.fd)
 
 let accept_n ch n =
   let l = ref [] in
@@ -1656,8 +1706,7 @@ let accept_n ch n =
            try
              for _i = 1 to n do
                if blocking && not (unix_readable ch.fd) then raise Retry;
-               let fd, addr = Unix.accept ch.fd in
-               l := (mk_ch ~blocking:false fd, addr) :: !l
+               l := accept_and_set_nonblock ch.fd :: !l
              done
            with
            | (Unix.Unix_error((Unix.EAGAIN | Unix.EWOULDBLOCK | Unix.EINTR), _, _) | Retry) when !l <> [] ->
@@ -2370,7 +2419,7 @@ let wait () = waitpid [] (-1)
 
 external system_job : string -> int job = "lwt_unix_system_job"
 
-external sys_exit : int -> 'a = "caml_sys_exit"
+external unix_exit : int -> 'a = "unix_exit"
 
 let system cmd =
   if Sys.win32 then
@@ -2383,7 +2432,7 @@ let system cmd =
           Unix.execv "/bin/sh" [| "/bin/sh"; "-c"; cmd |]
         with _ ->
           (* Do not run at_exit hooks *)
-          sys_exit 127
+          unix_exit 127
       end
     | id ->
       waitpid [] id >|= snd
