@@ -298,6 +298,17 @@ val read : file_descr -> bytes -> int -> int -> int Lwt.t
     except [Unix.Unix_error Unix.EAGAIN], [Unix.Unix_error Unix.EWOULDBLOCK] or
     [Unix.Unix_error Unix.EINTR]. *)
 
+val pread : file_descr -> bytes -> file_offset:int -> int -> int -> int Lwt.t
+(** [pread fd buf ~file_offset ofs len] on file descriptors allowing seek,
+    reads up to [len] bytes from [fd] at offset [file_offset] from the
+    beginning of the file, and writes them to [buf], starting at offset [ofs].
+
+    On Unix systems, the file descriptor position is unaffected. On Windows
+    it is changed to be just after the last read position.
+
+    The thread can fail with any exception that can be raised by [read] or
+    [lseek]. *)
+
 val write : file_descr -> bytes -> int -> int -> int Lwt.t
 (** [write fd buf ofs len] writes up to [len] bytes to [fd] from [buf], starting
     at buffer offset [ofs]. The function immediately evaluates to an Lwt thread,
@@ -315,9 +326,25 @@ val write : file_descr -> bytes -> int -> int -> int Lwt.t
     [Unix.single_write], except [Unix.Unix_error Unix.EAGAIN],
     [Unix.Unix_error Unix.EWOULDBLOCK] or [Unix.Unix_error Unix.EINTR]. *)
 
+val pwrite : file_descr -> bytes -> file_offset:int -> int -> int -> int Lwt.t
+(** [pwrite fd buf ~file_offset ofs len] on file descriptors allowing seek,
+    writes up to [len] bytes to [fd] from [buf], starting at buffer offset
+    [ofs]. The data is written at offset [file_offset] from the beginning
+    of [fd].
+
+    On Unix systems, the file descriptor position is unaffected. On Windows
+    it is changed to be just after the last written position.
+
+    The thread can fail with any exception that can be raised by [write] or
+    [lseek]. *)
+
 val write_string : file_descr -> string -> int -> int -> int Lwt.t
   (** See {!write}. *)
 
+val pwrite_string :
+  file_descr -> string -> file_offset:int -> int -> int -> int Lwt.t
+  (** See {!pwrite}. *)
+
 (** Sequences of buffer slices for {!writev}. *)
 module IO_vectors :
 sig
@@ -354,7 +381,9 @@ sig
       vectors in [vs] have zero bytes. *)
 
   val byte_count : t -> int
-  (** [byte_count vs] is the total number of bytes in [vs]. *)
+  (** [byte_count vs] is the total number of bytes in [vs].
+
+      @since 4.2.0 *)
 
   val system_limit : int option
   (** Some systems limit the number of I/O vectors that can be passed in a
@@ -666,7 +695,9 @@ val chdir : string -> unit Lwt.t
   (** Wrapper for [Unix.chdir] *)
 
 val getcwd : unit -> string Lwt.t
-  (** Wrapper for [Unix.getcwd] *)
+(** Wrapper for [Unix.getcwd]
+
+    @since 3.1.0 *)
 
 val chroot : string -> unit Lwt.t
   (** Wrapper for [Unix.chroot] *)
@@ -993,6 +1024,10 @@ type socket_float_option =
     Unix.socket_float_option =
   | SO_RCVTIMEO
   | SO_SNDTIMEO
+(** Note: these options are provided for the sake of completeness only. Lwt
+    places all sockets in non-blocking mode, for which these options are
+    meaningless. Use {!Lwt.pick} with {!Lwt_unix.sleep} or {!Lwt_unix.timeout}
+    for timeouts. *)
 
 val getsockopt : file_descr -> socket_bool_option -> bool
   (** Wrapper for [Unix.getsockopt] *)
