@@ -36,7 +36,7 @@ CAMLprim value lwt_unix_read(value fd, value buf, value vofs, value vlen)
         }
         if (err) {
             win32_maperr(err);
-            uerror("write", Nothing);
+            uerror("read", Nothing);
         }
         written = numwritten;
     }
